@@ -68,7 +68,7 @@ def start_loop():
 
 			elif c==16 :
 				if initial==1:
-					stat=int(os.popen("/usr/share/lfocus/v4l2-ctl -C torch_intensity|awk '{print $2}'").read())
+					stat=int(os.popen("/opt/lfocus/v4l2-ctl -C torch_intensity|awk '{print $2}'").read())
 					if int(stat)==0:
 						object.lfocus_led1(dbus_interface="com.nokia.lfocus_comms.lfocus_service")
 						initial=0
@@ -79,7 +79,7 @@ def start_loop():
 				break
 			elif c==17 :
 				if initial==1:
-					stat=int(os.popen("/usr/share/lfocus/v4l2-ctl -C torch_intensity|awk '{print $2}'").read())
+					stat=int(os.popen("/opt/lfocus/v4l2-ctl -C torch_intensity|awk '{print $2}'").read())
 					if int(stat)==1:
 						object.lfocus_led0(dbus_interface="com.nokia.lfocus_comms.lfocus_service")
 						initial=0
@@ -90,7 +90,7 @@ def start_loop():
 				break
 			elif c==18 :
 				if initial==1:
-					stat=int(os.popen("/usr/share/lfocus/v4l2-ctl -C indicator_intensity|awk '{print $2}'").read())
+					stat=int(os.popen("/opt/lfocus/v4l2-ctl -C indicator_intensity|awk '{print $2}'").read())
 					if int(stat)==0:
 						object.lfocus_rled1(dbus_interface="com.nokia.lfocus_comms.lfocus_service")
 						initial=0
@@ -101,7 +101,7 @@ def start_loop():
 				break
 			elif c==19 :
 				if initial==1:
-					stat=int(os.popen("/usr/share/lfocus/v4l2-ctl -C indicator_intensity|awk '{print $2}'").read())
+					stat=int(os.popen("/opt/lfocus/v4l2-ctl -C indicator_intensity|awk '{print $2}'").read())
 					if int(stat)==3:
 						object.lfocus_rled0(dbus_interface="com.nokia.lfocus_comms.lfocus_service")
 						initial=0
